==> bouml_2.9.3.tar.gz: bouml_2.9.3/genplugouts/html/cpp/UmlItem.h <==
#ifndef _UMLITEM_H
#define _UMLITEM_H


#include "UmlBaseItem.h"
#include <qcstring.h>
#include "aVisibility.h"
#include "Vector.h"
#include "FileWriter.h"

#include <qtextstream.h>
class UmlDiagram;
class UmlTypeSpec;

// This class is a mother class for all the other Uml* classes, this
// allows to generalize their management, declare virtual operations etc ...
//
// You can modify it as you want (except the constructor)
class UmlItem : public UmlBaseItem {
  public:
    UmlItem(void * id, const QCString & n) : UmlBaseItem(id, n) { refId = 0; };

    virtual ~UmlItem();

    virtual QCString sKind();

    //  Set the directory where the files will be generated
    //  initializing 'directory'.
    //
    //  Empty the directory in case it already exists
    void set_dir();

    virtual void memo_ref();

    void define();

    static void start_file(QCString f, QCString s, bool withrefs, UmlItem * x);

    static void end_file();

    static void ref_indexes();

    static void generate_indexes();

    static void frame();

    virtual void html(QCString pfix, unsigned int rank) = 0;

    void html(QCString pfix, unsigned int rank, QCString what);

    void html(const char * what, UmlDiagram * diagram);

    void chapter(QCString k, QCString pfix, unsigned int rank, QCString color);

    //bypass the comments at the beginning of the form
    
    const char * bypass_comment(const char * s);

    void manage_alias(const char *& p);

    virtual void write();

    virtual void write(QCString target);

    static void writeq(QCString s);

    static void writeq(char c);

    static void write(const UmlTypeSpec & t, bool cpp);

    static void write(aVisibility v);

    static void generate_index(Vector & v, QCString k, QCString r);

    static void sort(Vector & v);


  private:
    static void sort(Vector & v, int low, int high);

    bool gt(UmlItem * other);


  public:
    virtual QCString pretty_name();


  protected:
    static Vector all;

    unsigned int refId;

    static FileWriter fw;

    static QCString directory;

    static unsigned int nrefs;

    static QCString letters;

};

#endif

==> bouml_2.14.3.tar.gz: bouml_2.14.3/genplugouts/html/cpp/UmlItem.h <==
#ifndef _UMLITEM_H
#define _UMLITEM_H


#include "UmlBaseItem.h"
#include <qcstring.h>
#include "aVisibility.h"
#include "Vector.h"
#include "FileWriter.h"

#include <qtextstream.h>
class UmlDiagram;
class UmlTypeSpec;

// This class is a mother class for all the other Uml* classes, this
// allows to generalize their management, declare virtual operations etc ...
//
// You can modify it as you want (except the constructor)
class UmlItem : public UmlBaseItem {
  public:
    UmlItem(void * id, const QCString & n) : UmlBaseItem(id, n) { refId = 0; };

    virtual ~UmlItem();

    virtual QCString sKind();

    //  Set the directory where the files will be generated
    //  initializing 'directory'.
    //
    //  Empty the directory in case it already exists
    void set_dir();

    virtual void memo_ref();

    void define();

    static void start_file(QCString f, QCString s, bool withrefs, UmlItem * x);

    static void end_file();

    static void ref_indexes();

    static void generate_indexes();

    static void frame();

    virtual void html(QCString pfix, unsigned int rank) = 0;

    void html(QCString pfix, unsigned int rank, QCString what);

    void html(const char * what, UmlDiagram * diagram);

    void chapter(QCString k, QCString pfix, unsigned int rank, QCString color);

    //bypass the comments at the beginning of the form
    
    const char * bypass_comment(const char * s);

    void manage_alias(const char *& p);

    virtual void write();

    virtual void write(QCString target);

    static void writeq(QCString s);

    static void writeq(char c);

    static void write(const UmlTypeSpec & t, bool cpp);

    static void write(aVisibility v, bool cpp);

    static void generate_index(Vector & v, QCString k, QCString r);

    static void sort(Vector & v);


  private:
    static void sort(Vector & v, int low, int high);

    bool gt(UmlItem * other);


  public:
    virtual QCString pretty_name();


  protected:
    static Vector all;

    unsigned int refId;

    static FileWriter fw;

    static QCString directory;

    static unsigned int nrefs;

    static QCString letters;

};

#endif
